import QtQuick 2.4

Item {
    id: root

    state: "Closed"
    width: 80*main.hScaleFactor
    height: 120*main.vScaleFactor

    Connections {
        target: ibusMonitor

        onEnabledChanged: {
            console.log("ibus enabled changed:", ibusMonitor.enabled)
            if (!ibusMonitor.enabled) {
                // global engine was disabled, so select EN in dropdown
                selectList.setValue("")
            } else {
                selectList.setValue(ibusMonitor.globalEngine)
            }
        }

        onGlobalEngineChanged: {
            console.log("ibus globalengine", ibusMonitor.globalEngine)
            if (ibusMonitor.enabled) {
                selectList.setValue(ibusMonitor.globalEngine)
            }
        }
    }

    Connections {
        target: application

        onCurrentLanguageChanged: {
            selectList.setByLanguage(application.currentLanguage)
        }
    }

    Item {
        id: pressArea
        width: parent.width
        height: parent.height/3
        anchors { right: parent.right; top: parent.top; topMargin: 10*main.vScaleFactor }
        Image {
            id: downArrow
            source: "down_arrow.png"
            anchors { left: parent.left; verticalCenter: parent.verticalCenter }
        }
        Text {
            id: langText
            text: selectList.model ? selectList.model.get(selectList.currentIndex).label : ""
            color: "white"
            anchors {
                left: downArrow.right
                leftMargin: 5*main.hScaleFactor
                verticalCenter: parent.verticalCenter
            }
            font.pixelSize: 24*main.vScaleFactor
        }

        MouseArea {
            anchors.fill: parent
            z: 100
            onClicked: { root.state = "Open" }
        }
    }

    ListView {
        id: selectList
        anchors.fill: parent
        currentIndex: 0

        function setByLanguage(lang) {
            if (lang === "en") {
                ibusMonitor.doEnable(false)
            } else {
                if (!model) {
                    // This is not a supported language
                    return
                }

                var i
                for (i = 0; i < model.count; i++) {
                    if (model.get(i).langCode === lang) {
                        selectList.currentIndex = i
                        ibusMonitor.doSetGlobalEngine(model.get(i).engine)
                        return
                    }
                }
                // Fallback - Language not in list
                selectList.setValue("")
                ibusMonitor.doEnable(false)
            }
        }

        function setValue(engine) {
            if (!model) {
                return
            }
            var i
            for (i = 0; i < model.count; i++) {
                if (model.get(i).engine === engine) {
                    selectList.currentIndex = i
                    return
                }
            }
        }

        model: {
            if (application.currentLanguage === "zh") {
                return listModel_zh
            } else if (application.currentLanguage === "ja") {
                return listModel_jp
            }
        }

        delegate: listItemDelegate
    }

    Component {
        id: listItemDelegate
        Rectangle {
            width: ListView.view.width
            height: ListView.view.height/3
            border { color: main.colorBorder; width: 1*main.hScaleFactor }
            color: main.colorBackground
            opacity: ListView.isCurrentItem ? 1.0 : 0.5

            Text {
                anchors.centerIn: parent
                text: model.label
                color: "white"
                font.pixelSize: 16*main.vScaleFactor
                font.bold: parent.ListView.isCurrentItem
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    selectList.currentIndex = index
                    if (engine === "") {
                        ibusMonitor.doEnable(false)
                    } else {
                        ibusMonitor.doSetGlobalEngine(engine)
                    }
                    root.state = "Closed"
                }
            }
        }
    }

    ListModel {
        id: listModel_zh
        ListElement { label: "EN"; langCode: "en"; engine: "" }
        ListElement { label: "ZH"; langCode: "zh"; engine: "pinyin" }
    }

    ListModel {
        id: listModel_jp
        ListElement { label: "EN"; langCode: "en"; engine: "" }
        ListElement { label: "JP"; langCode: "ja"; engine: "anthy" }
    }

    states: [
        State {
            name: "Open"
            PropertyChanges { target: selectList; visible: true }
            PropertyChanges { target: pressArea; visible: false }
        },

        State {
            name: "Closed"
            PropertyChanges { target: selectList; visible: false }
            PropertyChanges { target: pressArea; visible: true }
        }
    ]
}
