import QtQuick 2.4
import QtQuick.Window 2.2 // For Screen
import Process 0.1
import "Keypad"

Rectangle {
    id: main
    width: keypad.width
    height: keypad.height
    color: "transparent"
    
    property color colorBorder: "#ba3e3e"
    property color colorBackground: "#000000"
    
    /**
     * Default to 1366x768 with a pixel density of 2.91251 px/mm
     */
    readonly property int defaultWidth: 1366
    readonly property int defaultHeight: 768
    readonly property real defaultPixelDensity: 2.91251
    /**
     * Calculate scale factors based on ratio of current screen to default and density of pixels
     */
    readonly property real hScaleFactor: (Screen.width/defaultWidth)//*(Screen.pixelDensity/defaultPixelDensity)
    readonly property real vScaleFactor: (Screen.height/defaultHeight)//*(Screen.pixelDensity/defaultPixelDensity)
    readonly property real scaleFactor: Math.min(hScaleFactor, vScaleFactor)

    Connections {
        target: application

        onCommandReceived: {
            var parts = cmd.split(" ")
            var command = parts[1]
            if (parts.length > 2) {
                var arg1 = parts[2]
                if (command === "lang") {
                    application.currentLanguage = arg1
                }
            }
        }
    }

    AlphaKeypad {
        id: keypad
        x: 0
        y: 0
        anchors { horizontalCenter: parent.horizontalCenter ; bottom: parent.bottom }
        visible: true
        onClose: application.hide()
        onKeyPress: {
            dotool.keypress(key)
        }

        onMultipress: {
            dotool.keypress(keylist)
        }
    }

    Process {
        id: dotool

        function keypress(keyOrArray) {
            var fullArgs = []
            if (ibusMonitor.enabled) {
                fullArgs.push("-f")
            }
            fullArgs = fullArgs.concat(keyOrArray)

            dotool.arguments = fullArgs
            start()
        }
        onReadyReadStandardError: {
            var output = new String(readAllStandardError())
            print(output)
        }
        onReadyReadStandardOutput: {
            var output = new String(readAllStandardOutput())
            print(output)
        }

        program: "qml/dotool.sh"
        arguments: ["a"]
    }
}
